.. _citation:

========
Citation
========

.. code:: 
  
  @Article{wortmann-2025-earth-scien,
    TITLE =	 {The Earth Science Box Modeling Toolkit (ESBMTK 0.14.0.11): a
                  Python Library for Research and Teaching},
    AUTHOR =	 {Wortmann, U. G. and Tsan, T. and Niazi, M. and Ma, I. A. and
                  Navasardyan, R. and Marun, M.-R. and Chede, B. S. and Zhong,
                  J. and Wolfe, M.},
    DOI =	{10.5194/gmd-18-1155-2025},
    JOURNAL =	 {Geoscientific Model Development},
    NUMBER =	 4,
    PAGES =	 {1155--1167},
    URL   =      {https://gmd.copernicus.org/articles/18/1155/2025/},
    VOLUME =	 18,
    YEAR =	 2025,
  }
